<?php

// Set the content width
if ( ! isset( $content_width ) )
	$content_width = 975; /* pixels */
  

/*-----------------------------------------------------------------------------------*/
/* Nav Walker
/* see http://codex.wordpress.org/Function_Reference/wp_nav_menu
/*-----------------------------------------------------------------------------------*/
          // Our nav walker
          include_once get_template_directory() . '/lib/walker-menu.php';
    
/*-----------------------------------------------------------------------------------*/
/* Theme setup
/*-----------------------------------------------------------------------------------*/

if ( ! function_exists( 'kciaotime_setup' ) ):

function kciaotime_setup() {
   
	// Enable theme translations
	load_theme_textdomain( 'kciaotime', get_template_directory() . '/languages' );

	$locale = get_locale();
	$locale_file = get_template_directory() . "/languages/$locale.php";
	if ( is_readable( $locale_file ) )
		require_once( $locale_file );
  
              // The title tag, only works on WordPress 4.1 or later
              add_theme_support( 'title-tag' );
  
	// Add default posts and comments RSS feed links to head
	add_theme_support( 'automatic-feed-links' );

	// Add stylesheet for the WYSIWYG editor
	add_editor_style();
    
              // Support Woocommerce
              add_theme_support('woocommerce');
      
              // Switch default core markup for search form, comment form, and comments to output valid HTML5.
	add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
	) );
  
	// Image thumbnails
              add_theme_support('post-thumbnails');
	
	// Register menu
	register_nav_menus( array(
		'primary' => __('Menu Primary','kciaotime'),
                            'top-menu' => __('Menu Top','kciaotime')
	) );
              
          // Custom backgrounds support
          $defaults_bg = array(
              'default-color'            => 'F4F4F4',
              'default-image'             => get_template_directory_uri() . '/images/background.png',
              'wp-head-callback'       => 'kciaotime_custom_background_cb',
              'admin_head_callback'     => '',
              'admin_preview_callback' => ''
          );
          add_theme_support ( 'custom-background', apply_filters( 'kciaotime_custom_background_args', $defaults_bg ) );
  
          // Custom header support
          $defaults_hd = array(
              'default-text-color'            => '7E7E7E',
              'default-image'           => '',
              'upload'                    => true,
              'wp-head-callback'       => 'kciaotime_header_style',
              'admin_head_callback'     => 'kciaotime_admin_header_style',
              'admin_preview_callback' => 'kciaotime_admin_header_img'
          );
          add_theme_support ( 'custom-header', apply_filters( 'kciaotime_custom_header_args', $defaults_hd ) );
           		
}
endif;

add_action( 'after_setup_theme', 'kciaotime_setup' );
    
/*----------------------------------------------------------------------------------------*/
/* Function custom background callback 
/*----------------------------------------------------------------------------------------*/
  
function kciaotime_custom_background_cb() {
    // Get the background image.
    $image_bg = get_background_image();
    // If there's an image, just call the normal WordPress callback. We won't do anything here.
    if ( !empty( $image_bg ) ) {
_custom_background_cb();
    return;
    // Get the background color.
    $color_bg = get_background_color();
    // If no background color, return.
    if ( empty( $color_bg ) )
return;
    // Use 'background' instead of 'background-color'.
    $style_bg = "background: {color};";
?>
<style type="text/css">body { <?php echo trim( $style_bg ); ?> }</style>
   <?php }
}
 
/*----------------------------------------------------------------------------------------*/
/* function custom header callback
/*----------------------------------------------------------------------------------------*/
  
if ( ! function_exists( 'kciaotime_header_style' ) ) :
/**
 * Styles the header image and text displayed on the blog
 *
 * @see kciaotime_custom_header_setup().
 */
function kciaotime_header_style() {
	$header_text_color = get_header_textcolor();

	// If no custom options for text are set, let's bail
	// get_header_textcolor() options: HEADER_TEXTCOLOR is default, hide text (returns 'blank') or any hex value
	if ( HEADER_TEXTCOLOR == $header_text_color ) {
		return;
	}

	// If we get this far, we have custom styles. Let's do this.
	?>
	<style type="text/css">
	<?php
		// Has the text been hidden?
		if ( 'blank' == $header_text_color ) :
	?>
		.site-branding {
			position: absolute;
			clip: rect(1px, 1px, 1px, 1px);
		}
	<?php
		// If the user has set a custom color for the text use that
		else :
	?>
		.site-title {
			color: #<?php echo $header_text_color; ?>;
		}
	<?php endif; ?>
	</style>
	<?php
}
endif; // kciaotime_header_style

if ( ! function_exists( 'kciaotime_admin_header_style' ) ) :
/**
 * Styles the header image displayed on the Appearance > Header admin panel.
 *
 * @see kciaotime_custom_header_setup().
 */
function kciaotime_admin_header_style() {
?>
	<style type="text/css">
		.appearance_page_custom-header #headimg {
			border: none;
		}
		#headimg {
			padding: 20px;
			background: #fff;
			font-size: 1.375em;
			text-align: center;
			-webkit-box-sizing: border-box;
			-moz-box-sizing: border-box;
			box-sizing: border-box;
		}
		#headimg h1,
		#desc {
		}
		#headimg h1 {
			margin: 0 0 10px;
			font-family: "Source Sans Pro", sans-serif;
			font-size: 3.6em;
			line-height: 1.1;
			font-weight: 900;
			text-transform: uppercase;
		}
		#headimg h1 a {
			text-decoration: none;
		}
		#desc {
			color: #b1b2b3 !important;
			font-family: "PT Serif", serif;
			font-size: 0.73em;
			line-height: 1.5;
			font-weight: normal;
			font-style: italic;
		}
		#headimg img {
			display: block;
			margin: 0 auto 20px auto;
		}
		#headimg img   h1 {
			margin-top: -5px;
		}
	</style>
<?php
}
endif; // kciaotime_admin_header_style

if ( ! function_exists( 'kciaotime_admin_header_image' ) ) :
/**
 * Custom header image markup displayed on the Appearance > Header admin panel.
 *
 * @see kciaotime_custom_header_setup().
 */
function kciaotime_admin_header_image() {
	$style = sprintf( ' style="color:#%s;"', get_header_textcolor() );
?>
	<div id="headimg">
		<?php if ( get_header_image() ) : ?>
			<img src="<?php header_image(); ?>" alt="">
		<?php endif; ?>
		<h1 class="displaying-header-text"><a id="name"<?php echo $style; ?> onclick="return false;" href="<?php echo esc_url( home_url( '/' ) ); ?>"><?php bloginfo( 'name' ); ?></a></h1>
		<div class="displaying-header-text" id="desc"><?php bloginfo( 'description' ); ?></div>
	</div>
<?php
}
endif;
  
/*-----------------------------------------------------------------------------------*/
/* JavaScript & CSS
/*-----------------------------------------------------------------------------------*/
              // Register Fauna One Google font for Kciaotime.
function kciaotime_font_url() {
	$font_url = '';
	// Translators: If there are characters in your language that are not supported  by Fauna One, translate this to 'off'. Do not translate into your own language.
	if ( 'off' !== _x( 'on', 'Fauna One font: on or off', 'kciaotime' ) ) {
		$query_args = array(
			'family' => urlencode( 'Fauna One:300,400,700,900,300italic,400italic,700italic' ),
			'subset' => urlencode( 'latin,latin-ext' ),
		);
		$font_url = add_query_arg( $query_args, '//fonts.googleapis.com/css' );
	}
	return $font_url;
}
    
function kciaotime_enqueue_scripts()
 {
          wp_enqueue_script('kciaotime_dropdown', get_template_directory_uri() . '/lib/js/dropdown.js', array('jquery'));
          wp_enqueue_script('kciaotime_touchdown', get_template_directory_uri() . '/lib/js/touchdown.js', array('jquery'));
          wp_enqueue_script('kciaotime_flexslider', get_template_directory_uri() . '/lib/js/jquery.flexslider.js', array('jquery'));
          wp_enqueue_script('kciaotime_scriptsmin', get_template_directory_uri() . '/lib/js/scripts.min.js', array('jquery'));
          wp_enqueue_script('kciaotime_hoverIntent', get_template_directory_uri() . '/lib/js/hoverIntent.js');
          
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
	wp_enqueue_script( 'comment-reply' );
	}
}
add_action('wp_enqueue_scripts', 'kciaotime_enqueue_scripts');

function kciaotime_enqueue_css() {
          wp_enqueue_style('fontawesome', get_template_directory_uri() . '/lib/css/font-awesome.css');
          wp_enqueue_style('top_menu', get_template_directory_uri() . '/top-menu.css');
          wp_enqueue_style('fauna-one', kciaotime_font_url(), array(), null);
          wp_enqueue_style('ie_css', get_template_directory_uri() . '/lib/css/ie.css');
          wp_enqueue_style('default_css', get_template_directory_uri() . '/lib/css/defaults.css');
          wp_enqueue_style('default_stylesheet', get_stylesheet_directory_uri() . '/style.css');
}
add_action('wp_print_styles', 'kciaotime_enqueue_css');

/*-----------------------------------------------------------------------------------*/
/* Display <title> tag
/*-----------------------------------------------------------------------------------*/
  
    if( version_compare( $GLOBALS['wp_version'], '4.1', '<' ) ) :
  
    // filter function for wp_title
function kciaotime_filter_wp_title( $old_title, $sep, $sep_location ){
 
    // add padding to the sep
    $ssep = ' ' . $sep . ' ';
     
    // find the type of index page this is
    if( is_category() ) $insert = $ssep . __('Category','kciaotime');
    elseif( is_tag() ) $insert = $ssep . __('Tag','kciaotime');
    elseif( is_author() ) $insert = $ssep . __('Author','kciaotime');
    elseif( is_year() || is_month() || is_day() ) $insert = $ssep . __('Archives','kciaotime');
    elseif( is_home() ) $insert = $ssep . get_bloginfo('description');
    else $insert = NULL;
     
    // get the page number we're on (index)
    if( get_query_var( 'paged' ) )
    $num = $ssep . __('Page ','kciaotime') . get_query_var( 'paged' );
     
    // get the page number we're on (multipage post)
    elseif( get_query_var( 'page' ) )
    $num = $ssep . __('Page ','kciaotime') . get_query_var( 'page' );
     
    // else
    else $num = NULL;
     
    // concoct and return new title
    return get_bloginfo( 'name' ) . $insert . $old_title . $num;
}

add_filter( 'wp_title', 'kciaotime_filter_wp_title', 10, 3 );

function kciaotime_rss_title($title) {
    /* need to fix our add a | blog name to wp_title */
    $ft = str_replace(' | ','',$title);
    return str_replace(get_bloginfo('name'),'',$ft);
}
add_filter('get_wp_title_rss', 'kciaotime_rss_title',10,1);
  
    // Adding Title for site older than WordPress 4.1
function kciaotime_render_title() {

	?>
	<title><?php wp_title(); ?></title>
	<?php
	}
add_action( 'wp_head', 'kciaotime_render_title' );
    endif;
  
/*-----------------------------------------------------------------------------------*/
/* Excerpt config
/*-----------------------------------------------------------------------------------*/
function kciaotime_excerptlength_themes($length) {
    return 60;
}
function kciaotime_excerptmore($more)
{
	return '... <div class="readmore"><a  rel="bookmark" href="' . get_permalink( get_the_ID() ) . '">Continue reading &raquo;</a></div>';
}
        add_filter('excerpt_length', 'kciaotime_excerptlength_themes');
        add_filter('excerpt_more', 'kciaotime_excerptmore');
    
/*-----------------------------------------------------------------------------------*/
/* Append post content pagination right after post content
/*-----------------------------------------------------------------------------------*/
function kciaotime_post_pagination($content) {
    
    if ( is_single() ) {
        $content .= wp_link_pages( array( 'before' => '<div class="navigation clearfix">' . __( 'Pages:', 'kciaotime' ), 'after' => '</div>', 'echo' => 1 ) );
    }
	return $content;
}
add_filter('the_content','kciaotime_post_pagination', 10);
  
add_filter('use_default_gallery_style', '__return_false' ); // Remove inline style of WordPress Gallery Shortcode
  
/*-----------------------------------------------------------------------------------*/
/* Get our wp_nav_menu() fallback, wp_page_menu(), to show a home link.
/*-----------------------------------------------------------------------------------*/
function kciaotime_page_menu_args( $args ) {
	$args['show_home'] = true;
	return $args;
}
add_filter( 'wp_page_menu_args', 'kciaotime_page_menu_args' );
  
/*-----------------------------------------------------------------------------------*/
/* Register widgetized area and update sidebar with default widgets
/*-----------------------------------------------------------------------------------*/
function kciaotime_widgets_init() {
	register_sidebar( array(
		'name' => __('Main Sidebar', 'kciaotime'),
                             'id' => 'main-sidebar',
		'before_widget' => '<ul class="widget-container"><li id="%1$s" class="widget %2$s">',
		'after_widget' => '</li></ul>',
		'before_title' => '<h3 class="widgettitle">',
		'after_title' => '</h3>',
	));
              register_sidebar( array(
                            'name' => __('Top Widget', 'kciaotime'),
                            'id' => 'top-widget',
                            'before_widget' => '<ul class="widget-container"><li id="%1$s" class="widget %2$s">',
                            'after_widget' => '</li></ul>',
                            'before_title' => '<h3 class="widgettitle">',
                            'after_title' => '</h3>',
              ));
	register_sidebar( array(
		'name' => __('Footer Left', 'kciaotime'),
                            'id' => 'footer-left',
		'before_widget' => '<ul class="widget-container"><li id="%1$s" class="widget %2$s">',
		'after_widget' => '</li></ul>',
		'before_title' => '<h3 class="widgettitle">',
		'after_title' => '</h3>',
	));
	register_sidebar( array(
		'name' => __('Footer Middle', 'kciaotime'),
                             'id' => 'footer-middle',
		'before_widget' => '<ul class="widget-container"><li id="%1$s" class="widget %2$s">',
		'after_widget' => '</li></ul>',
		'before_title' => '<h3 class="widgettitle">',
		'after_title' => '</h3>',
	));
             register_sidebar( array(
                           'name' => __('Footer Right', 'kciaotime'),
                            'id' => 'footer-right',
                           'before_widget' => '<ul class="widget-container"><li id="%1$s" class="widget %2$s">',
                           'after_widget' => '</li></ul>',
                           'before_title' => '<h3 class="widgettitle">',
                           'after_title' => '</h3>',
              ));
}
add_action('widgets_init', 'kciaotime_widgets_init');
  
/*-----------------------------------------------------------------------------------*/
/* Comments
/*-----------------------------------------------------------------------------------*/

if ( ! function_exists( 'kciaotime_comment' ) ) :

function kciaotime_comment( $comment, $args, $depth ) {
        $GLOBALS['comment'] = $comment;
        ?>
            <li <?php comment_class(); ?> class="depth-1" id="<?php comment_ID(); ?>">
                <div id="<?php comment_ID(); ?>" class="comment-body">
                    <div class="comment-author vcard">
                        <?php echo get_avatar( $comment, 32 ); ?>
                            <?php if ( $comment->comment_approved == '0' ) : ?>
                                <em><?php _e( 'Your comment is awaiting moderation.', 'kciaotime' ); ?></em>
                            <?php endif; ?>
                                <cite class="fn"><?php echo get_comment_author_link(); ?></cite>
                    </div>
                    <div class="comment-meta commentmetadata"><a href="<?php comment_ID(); ?>"><?php comment_time( 'F j, Y g:i a' ); ?></a>
                    </div>
                        <p><?php the_comment(); ?></p>                                     <div class="reply">
                        <?php comment_replay_link( array_merge( $args, array( 'depth' => $depth, 'max-depth' => $args['max-depth'] ) ) ); ?>
                    </div>
                </div>
            </li>
        <?php
}
  
endif;
    
/*-----------------------------------------------------------------------------------*/
/*	Add buttons to tinyMCE
/*-----------------------------------------------------------------------------------*/		
add_action('init', 'kciaotime_add_button');
  
function kciaotime_add_button() {  
   if ( current_user_can('edit_posts') &&  current_user_can('edit_pages') )  
   {  
     add_filter('mce_external_plugins', 'kciaotime_add_plugin');  
     add_filter('mce_buttons', 'kciaotime_register_button');  
   }  
}  
  
function kciaotime_register_button($buttons) {  
   array_push($buttons, "button", "list", "tabs", "accordion");  
   return $buttons;  
}  
  
function kciaotime_add_plugin($plugin_array) {
   $plugin_array['button'] = get_template_directory_uri().'/lib/tinymce/customcodes.js';
   $plugin_array['list'] = get_template_directory_uri().'/lib/tinymce/customcodes.js';
   $plugin_array['tabs'] = get_template_directory_uri().'/lib/tinymce/customcodes.js';
   $plugin_array['accordion'] = get_template_directory_uri().'/lib/tinymce/customcodes.js';
   return $plugin_array;
}
   
/*-----------------------------------------------------------------------------------*/
/* Favicon image
/*-----------------------------------------------------------------------------------*/
if ( ! function_exists( 'has_site_icon' ) || ! has_site_icon() ) :
 
if ( ! function_exists( 'kciaotime_favicon_icon' ) ) :
  
function kciaotime_favicon_icon() {
    $favicon_icon = get_option( 'kciaotime_upload_favicon_icon' );
    if ( get_option( 'kciaotime_display_favicon_icon' ) == 1 ) :
        if ( ! get_option( 'kciaotime_upload_favicon_icon' ) ) {
        $favicon_icon = get_template_directory_uri() . '/images/favicon.ico';
        }
    ?>
        <link rel="shortcut icon" href="<?php echo $favicon_icon; ?>" type="image/x-icon" />
        <?php
    endif;
}
  
endif;
// Load in header blog page
add_action('wp_head', 'kciaotime_favicon_icon');
// Load in the header admin
add_action('admin_head', 'kciaotime_favicon_icon');
 
endif;
  
/*-----------------------------------------------------------------------------------*/
/* Load Customizer
/*-----------------------------------------------------------------------------------*/
    define( 'CUSTOMIZER_DIRECTORY', get_template_directory_uri() . '/lib/' );
    require_once dirname( __FILE__ ) . '/lib/customizer.php';
